==> roco-oil-card-settle-api-0.0.2-20200227.092854-10-sources.jar: com/roco/settle/api/service/SettleCapitalAccountService.java <==
package com.roco.settle.api.service;

import com.roco.settle.api.entity.SettleCapitalAccount;
import com.roco.settle.api.request.base.CommonQueryPageRequest;
import com.roco.settle.api.request.base.CommonRequest;
import com.roco.settle.api.request.settlecapital.SettleCapitalAccountBatchReq;
import com.roco.settle.api.request.settlecapital.SettleCapitalAccountPageReq;
import com.roco.settle.api.request.settlecapital.SettleCapitalAccountReq;
import com.roco.settle.api.response.base.CommonQueryPageResponse;
import com.roco.settle.api.response.base.CommonResponse;
import com.roco.settle.api.response.settlecapital.SettleCapitalAccountDetailResp;

import java.util.List;

/**
 * 结算业务资金账户
 * @author zhanghongshan
 */
public interface SettleCapitalAccountService {


    /**
     * 创建资金账户
     * @param request
     * @return
     */
    CommonResponse<Boolean> saveSettleCapitalAccount(CommonRequest<SettleCapitalAccountReq> request);


    /**
     * 分页查询资金账户
     * @param pageRequest
     * @return
     */
    CommonQueryPageResponse<SettleCapitalAccount> pageSettleCapitalAccount(CommonQueryPageRequest<SettleCapitalAccountPageReq> pageRequest);


    /**
     * 更新状态
     * @param updateRequest
     * @return
     */
    CommonResponse<Boolean> updateStatusSettleCapitalAccount(CommonRequest<SettleCapitalAccountReq> updateRequest);

    /**
     * 批量开户
     * @param batchRequest
     * @return
     */
    CommonResponse<List<SettleCapitalAccount>> batchCreateCapitalAccount(CommonRequest<SettleCapitalAccountBatchReq> batchRequest)throws Exception;

    /**
     * 资金账户查询详情
     * @param request
     * @return
     */
    CommonResponse<SettleCapitalAccountDetailResp> detailCapitalAccount(CommonRequest<SettleCapitalAccountReq> request);
}

==> roco-oil-card-settle-api-1.3.18.20200617.031530-2-sources.jar: com/roco/settle/api/service/SettleCapitalAccountService.java <==
package com.roco.settle.api.service;

import com.roco.settle.api.entity.SettleCapitalAccount;
import com.roco.settle.api.entity.capital.SettleAccountUseAmountDetailStatistic;
import com.roco.settle.api.request.base.CommonQueryPageRequest;
import com.roco.settle.api.request.base.CommonRequest;
import com.roco.settle.api.request.settlecapital.*;
import com.roco.settle.api.response.base.CommonQueryPageResponse;
import com.roco.settle.api.response.base.CommonResponse;
import com.roco.settle.api.response.settlecapital.SettleCapitalAccountDetailResp;

import java.util.List;
import java.util.Map;

/**
 * 结算业务资金账户
 * @author zhanghongshan
 */
public interface SettleCapitalAccountService {


    /**
     * 创建资金账户
     * @param request
     * @return
     */
    CommonResponse<Boolean> saveSettleCapitalAccount(CommonRequest<SettleCapitalAccountReq> request);


    /**
     * 分页查询资金账户
     * @param pageRequest
     * @return
     */
    CommonQueryPageResponse<SettleCapitalAccount> pageSettleCapitalAccount(CommonQueryPageRequest<SettleCapitalAccountPageReq> pageRequest);


    /**
     * 更新状态
     * @param updateRequest
     * @return
     */
    CommonResponse<Boolean> updateStatusSettleCapitalAccount(CommonRequest<SettleCapitalAccountReq> updateRequest);

    /**
     * 批量开户
     * @param batchRequest
     * @return
     */
    CommonResponse<List<SettleCapitalAccount>> batchCreateCapitalAccount(CommonRequest<SettleCapitalAccountBatchReq> batchRequest)throws Exception;

    /**
     * 资金账户查询详情
     * @param request
     * @return
     */
    CommonResponse<SettleCapitalAccountDetailResp> detailCapitalAccount(CommonRequest<SettleCapitalAccountReq> request);


    /**
     * 根据业务主体，跟  基点编码查询 资金账户
     * @param request
     * @return
     */
    CommonResponse<SettleCapitalAccount> getByEnterpriseCodeAndBiz(CommonRequest<SettleCapitalAccountReq> request);



    /**
     * 资金账户存入
     * @param request
     * @return
     */
    CommonResponse<Boolean> remittance(CommonRequest<SettleAccountRemittanceDetailReq> request);

    /**
     * 资金账户费用发生
     * @param request
     * @return
     */
    CommonResponse<Boolean> useAmount(CommonRequest<SettleAccountUseAmountDetailReq> request);

    /**
     * 资金账户使用明细统计
     * @param request
     * @return
     */
    CommonQueryPageResponse<SettleAccountUseAmountDetailStatistic> useAmountStatistic(CommonQueryPageRequest<SettleCapitalAccountReq> request);

    /**
     * 油卡费用使用情况汇总
     * @param request
     * @return
     */
    CommonResponse<Map<String,Object>> oilcardDetail(CommonRequest<SettleCapitalAccountReq> request);
}
